# Copyright © 2021 Arrikto Inc.  All Rights Reserved.

"""This script takes a dataset as input and splits it."""

import os
import sys
import json

from sklearn.model_selection import train_test_split

if __name__ == "__main__":
    # Load dataset from the input args
    file_x = sys.argv[1]
    file_y = sys.argv[2]
    with open(file_x, "r") as fp:
        x = json.load(fp)
    with open(file_y, "r") as fp:
        y = json.load(fp)
    print("Dataset read successfully.")

    # Read the file paths to write the outputs
    x_test_out_filepath = sys.argv[3]
    y_test_out_filepath = sys.argv[4]

    # Create the parent directories for the output files
    if not os.path.exists(os.path.dirname(x_test_out_filepath)):
        os.makedirs(os.path.dirname(x_test_out_filepath))
    if not os.path.exists(os.path.dirname(y_test_out_filepath)):
        os.makedirs(os.path.dirname(y_test_out_filepath))

    print("Creating a test set...")
    _, x_test, _, y_test = train_test_split(x, y, test_size=0.6)
    print("Test dataset created successfully.")

    print("Saving files to marshal directory...")
    with open("/kale_marshal_dir/x_test.txt", "w") as f:
        json.dump(x_test, f)
    with open("/kale_marshal_dir/y_test.txt", "w") as f:
        json.dump(y_test, f)
    print("Saved files to marshal directory successfully.")

    print("Writing output files...")
    with open(x_test_out_filepath, "w") as f:
        f.write("/kale_marshal_dir/x_test.txt")
    with open(y_test_out_filepath, "w") as f:
        f.write("/kale_marshal_dir/y_test.txt")
    print("Done")
